package com.example.mynotepad.MenuFeatures.AllArchivedNotes;

import androidx.appcompat.app.AppCompatActivity;
import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentTransaction;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import android.os.Bundle;
import android.view.View;
import android.widget.FrameLayout;
import android.widget.LinearLayout;
import android.widget.Toast;

import com.example.mynotepad.MenuFeatures.AllArchivedNotes.MyArchivedNotesRecyclerView.*;
import com.example.mynotepad.MenuFeatures.AllNotes.DataBase.DateEntity;
import com.example.mynotepad.MenuFeatures.AllNotes.AllNotesActivity;
import com.example.mynotepad.MenuFeatures.AllNotes.DataBase.Note;
import com.example.mynotepad.MenuFeatures.AllNotes.MyNoteRecyclerView.MyNote;
import com.example.mynotepad.MenuFeatures.AllNotes.Note.NoteFragment;
import com.example.mynotepad.MenuFeatures.Calender.MyCalenderRecyclerView.TimePicker.MyDate;
import com.example.mynotepad.MenuFeatures.CustomToolbarOption;
import com.example.mynotepad.MenuFeatures.CustomToolbarOptionListener;
import com.example.mynotepad.R;

import java.util.ArrayList;
import java.util.List;

import static com.example.mynotepad.MainActivity.noteDataBase;

public class ArchivedNotesActivity extends AppCompatActivity {

    private FrameLayout fragPlace;
    private LinearLayout allNoteListAndTitle;
    private CustomToolbarOption customToolbarOption;
    private FrameLayout allNoteToolBar;
    private RecyclerView recyclerView;
    private MyArchivedAdaptor myarchivedAdaptor;
    private List<Note> entityNotes;
    private List<DateEntity> entityDates;
    private List<MyNote> myNotes;
    private List<MyDate> myDates;
    private DateOrNote chosenDateOrNote;
    private FragmentTransaction fragmentTransaction;
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_achived_notes);
        init();
    }


    private void init() {
        // get data from database
        setAllNoteListAndTitles();
        setAllDateNoteListAndTitles();

        customToolbarOption = findViewById(R.id.customToolbarOption2);
        customToolbarOption.setVisibility(View.GONE);
        allNoteToolBar = findViewById(R.id.allNotesToolbar2);
        allNoteToolBar.setEnabled(false);
        allNoteListAndTitle = findViewById(R.id.allNoteListAndTitle2);
        fragPlace = findViewById(R.id.fragmentPlace2);
        fragPlace.setVisibility(View.GONE);


        // show list with recycler view
        recyclerView = findViewById(R.id.recyclerView2);
        LinearLayoutManager linearLayoutManager = new LinearLayoutManager(this, LinearLayoutManager.VERTICAL, false);
        myarchivedAdaptor = new MyArchivedAdaptor(myNotes, myDates);
        recyclerView.setAdapter(myarchivedAdaptor);
        recyclerView.setLayoutManager(linearLayoutManager);

        addListeners();
    }

    private void addListeners() {

        // add listener to recyclerView
        myarchivedAdaptor.setOnArchivedItemClickListener(new OnArchivedItemClickListener() {
            @Override
            public void onItemClicked(DateOrNote item) {
                chosenDateOrNote = item;
                if (item.getType().equals("note")){
                    //set noteFragment data
                    final Bundle bundle = new Bundle();
                    bundle.putString("title", item.getTitle());
                    bundle.putString("bodyTxt", item.getDescription());

                    //change the fragment
                    fragPlace.setVisibility(View.VISIBLE);
                    allNoteListAndTitle.setVisibility(View.GONE);
                   //todo
                }
                else if (item.getType().equals("date")){
                    //todo go to fragment
                }

            }

            @Override
            public void onItemLongClicked(DateOrNote item) {
                chosenDateOrNote = item;
                customToolbarOption.setVisibility(View.VISIBLE);
                customToolbarOption.hideRecycleBin();
                allNoteToolBar.setVisibility(View.GONE);
            }
        });


        //add listener to custom toolbar option and set being archived or not to be saved in database
        customToolbarOption.setCustomToolbarOptionListener(new CustomToolbarOptionListener() {
            @Override
            public void onStarClicked() {
                customToolbarOption.setBlackStar();
                myarchivedAdaptor.getDateOrNoteList().remove(chosenDateOrNote);
                updateToUnarchiveInDataBase();
                Toast.makeText(ArchivedNotesActivity.this, "unarchived", Toast.LENGTH_SHORT).show();
            }


            @Override
            public void onDeleteClicked() {
            }

            @Override
            public void onCloseClicked() {
                closeClicked(customToolbarOption);
            }
        });
    }


    private void updateToUnarchiveInDataBase() {
        if (chosenDateOrNote.getType().equals("note")){
            noteDataBase.noteDao().updateNote(chosenDateOrNote.getTitle() , chosenDateOrNote.getDescription() , false , chosenDateOrNote.getId());
        }
        else if(chosenDateOrNote.getType().equals("date")){
            noteDataBase.dateNoreDAO().updateDate(chosenDateOrNote.getTitle() , chosenDateOrNote.getDescription() , false , chosenDateOrNote.getId());
        }
    }


    private void setAllNoteListAndTitles() {
        entityNotes = noteDataBase.noteDao().getAll();
        myNotes = new ArrayList<>();
        for (Note note : entityNotes) {
            MyNote myNote = new MyNote(note.getTitle(), note.getDescription(), note.isarchived() , note.getID());
            myNotes.add(myNote);
        }
    }

    private void setAllDateNoteListAndTitles() {
        //get data from database to set in recyclerView
        entityDates = noteDataBase.dateNoreDAO().getAllDateNotes();
        myDates = new ArrayList<>();
        for (DateEntity dateEntity : entityDates) {
            MyDate myDate = new MyDate(dateEntity.getDate(), dateEntity.getDescription(), dateEntity.isarchived() , dateEntity.getID());
            myDates.add(myDate);
        }
    }

    public void replaceFragment(Fragment fragment) {
        fragmentTransaction = getSupportFragmentManager().beginTransaction();
        fragmentTransaction.replace(fragPlace.getId(), fragment);
        fragmentTransaction.commit();
    }

    protected void closeClicked(CustomToolbarOption customToolbarOption) {
        customToolbarOption.setVisibility(View.GONE);
        allNoteToolBar.setVisibility(View.VISIBLE);
    }
}